(assert-defined & syms)Ensures that zero or more symbols are defined.
Ensures that zero or more symbols are defined.
(decode-json source)Parses a JSON stream or string.
Parses a JSON stream or string.
(encode-path root-dir file-path)Encodes a file path for use in a URL.
Encodes a file path for use in a URL.
(find-value m ks)Finds the value associated with a key in a map. The first non-nil value associated with one of the given keys is returned. With the current implementation, the keys provided must be keywords.
Finds the value associated with a key in a map. The first non-nil value associated with one of the given keys is returned. With the current implementation, the keys provided must be keywords.
(to-millis timestamp)Converts a formatted timestamp to milliseconds since the epoch.
Converts a formatted timestamp to milliseconds since the epoch.
(to-utc timestamp)Converts a formatted timestamp to UTC.
Converts a formatted timestamp to UTC.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |